@@ -106,20 +106,18 @@ Q_SIGNALS:
     /**
      * Is emitted after the loading triggered by KFileMetaDataProvider::setItems()
      * has been finished.
+     *
+     * Can be emitted multiple times to indicate data changes
      */
     void loadingFinished();
 
-    void urlActivated(const KUrl& url);
-
-    void dataChangeStarted();
-    void dataChangeFinished();
-
 private:
     class Private;
     Private* const d;
 
     Q_PRIVATE_SLOT(d, void slotLoadingFinished(ResourceLoader* loader))
     Q_PRIVATE_SLOT(d, void slotLoadingFinished(KJob* job))
+    Q_PRIVATE_SLOT(d, void insertBasicData());
 };
 
 }
